import React, { Fragment } from 'react';
import { SearchOutlined, SyncOutlined } from '@ant-design/icons';
import '@ant-design/compatible/assets/index.css';
import { Card, Table, notification, Button, Row, Col, Input, Divider, Select, Badge, Popconfirm, Form } from 'antd';
import * as Format from '@/utils/Format';
import { PageHeaderWrapper } from '@ant-design/pro-layout';
import { getAdminPageList, deleteAdmin, enableAdmin, disableAdmin } from '../services/api';
import router from 'umi/router';
import styles from './ManagerList.less';
import Ellipsis from '@/components/Ellipsis';
import Zmage from 'react-zmage';
import { objFilter } from '@/utils/Help';
import { SettingOutlined, PlusOutlined } from '@ant-design/icons'
import AddManager from './components/AddManager'


const { Column } = Table;
const Option = Select.Option;
const FormItem = Form.Item;

class ManagerList extends React.Component {
  constructor(props) {
    super(props);
    this.formRef = React.createRef()
    this.state = {
      pagination: {
        pageSize: 20,
        current: 1,
        total: 0,
      },
      info: {}
    };
  }

  componentDidMount() {
    const storageParams = sessionStorage.getAdminPageList;
    if (storageParams) {
      const params = JSON.parse(storageParams);
      const pagination = {
        pageSize: params.pageSize,
        current: params.pageIndex,
        total: 0,
      };
      const formFields = {
        adminName: params.adminName,
        status: params.status,
        adminPhone: params.adminPhone,
      };
      this.formRef.current.setFieldsValue(formFields);
      this.setState({ pagination }, () => {
        //获取子账号列表
        this.getAdminPageList(this.state.pagination.current);
      });
    } else {
      this.getAdminPageList(this.state.pagination.current);
    }
  }

  //获取子账号列表
  getAdminPageList(pageIndex) {
    const { pagination, loading } = this.state;
    if (loading) return;
    this.setState({ loading: true }, async () => {
      const { adminName, status, adminPhone } = this.formRef.current.getFieldsValue();
      const params = {
        status, //直播状态
        adminName, //子账号姓名
        adminPhone, //推流状态
        pageIndex: pageIndex ? pageIndex : pagination.current,
        pageSize: pagination.pageSize,
      };
      objFilter(params); //去除空字段
      const res = await getAdminPageList(params);
      if (res.code === 'OK') {
        const list = res.data.list || [];
        pagination.current = params.pageIndex;
        pagination.total = res.data.total;
        this.setState({ list, loading: false, pagination });
        sessionStorage.getAdminPageList = JSON.stringify(params);
      } else {
        this.setState({ loading: false });
      }
    });
  }

  // 翻页
  handlePage(page) {
    const pageIndex = page.current;
    this.getAdminPageList(pageIndex);
  }

  //输入搜索名称
  handleSearchName(e) {
    this.setState({ adminName: e.target.value });
  }

  //选择子账号状态
  onSelectStatus(status) {
    this.setState({ status });
  }

  //跳转
  linkTo(url) {
    router.push(url);
  }

  //重置搜索
  resetSearch() {
    this.formRef.current.resetFields();
    sessionStorage.removeItem('getAdminPageList');
  }

  testLog() {
    console.log(this.state);
  }

  //渲染搜索条件
  renderSearch() {
    const { loading } = this.state;
    return (
      <div className={styles.tableListForm}>
        <Form layout="inline" ref={this.formRef}>
          <Row gutter={{ md: 8, lg: 24, xl: 48 }} type="flex" justify="start">
            <Col md={8} sm={24}>
              <FormItem
                label="子账号名称"
                name="adminName"
                rules={[{ required: false, message: '请输入子账号名称' }]}
              >
                <Input placeholder="请输入子账号名称" allowClear />
              </FormItem>
            </Col>

            <Col md={8} sm={24}>
              <FormItem
                label="手机号"
                name="adminPhone"
                rules={[{ required: false, message: '请输入手机号' }]}
              >
                <Input placeholder="请输入手机号" allowClear />
              </FormItem>
            </Col>

            <Col md={8} sm={24}>
              <FormItem
                label="状态"
                name="status"
                rules={[{ required: false, message: '请选择状态' }]}
              >
                <Select allowClear placeholder="请选择状态">
                  <Option key={1} value={1}>
                    <Badge status="success" text="启用" />
                  </Option>
                  <Option key={0} value={0}>
                    <Badge status="error" text="禁用" />
                  </Option>
                </Select>
              </FormItem>
            </Col>
          </Row>
          <div className={styles.submitButtons}>
            <Button
              type="primary"
              loading={loading}
              icon={<SearchOutlined />}
              onClick={this.getAdminPageList.bind(this, 1)}
            >
              查询
            </Button>
            <Button style={{ marginLeft: 20 }} icon={<SyncOutlined />} onClick={this.resetSearch.bind(this)}>
              重置
            </Button>
          </div>
        </Form>
      </div>
    );
  }

  //删除子账号
  deleteAdmin(adminId) {
    const { deteleLoading } = this.state;
    if (deteleLoading) return;
    this.setState({ deteleLoading: true }, async () => {
      const res = await deleteAdmin({ adminId });
      if (res.success) {
        notification.success({
          message: '子账号删除成功',
        });
        this.setState({ deteleLoading: false }, () => {
          this.getAdminPageList(this.state.pagination.current);
        });
      } else {
        this.setState({ deteleLoading: false });
      }
    });
  }

  //打开编辑
  opeUpdate = (info) => {
    this.setState({ actionType: 'update', info, actionModal: true })
  }

  //禁用动效
  handleStatus(adminId, needStatus) {
    const { handleStatusLoading } = this.state;
    if (handleStatusLoading) return;
    this.setState({ handleStatusLoading: true }, async () => {
      const res = needStatus === 0 ? await disableAdmin({ adminId }) : await enableAdmin({ adminId });
      if (res.success) {
        notification.success({
          message: `${needStatus === 0 ? '禁用' : '启用'}成功`,
        });
        this.setState({ handleStatusLoading: false }, () => {
          this.getAdminPageList(this.state.pagination.current);
        });
      } else {
        this.setState({ handleStatusLoading: false });
      }
    });
  }

  render() {
    const { list } = this.state;
    return (
      <PageHeaderWrapper
        title={<span onClick={this.testLog.bind(this)}>{this.props.route.name}</span>}
        extra={
          <Button type="primary" icon={<PlusOutlined />} onClick={() => this.setState({ actionModal: true, actionType: 'add' })}>添加子账号</Button>
        }
      >
        <Card title="子账号列表">
          {this.renderSearch()}
          <Table
            rowKey="adminId"
            loading={this.state.loading}
            pagination={this.state.pagination}
            onChange={this.handlePage.bind(this)}
            dataSource={list}
          >
            {/* <Column
              title="头像"
              dataIndex="adminAvatar"
              key="adminAvatar"
              render={adminAvatar => (
                <Zmage
                  className={styles.productPic}
                  src={adminAvatar + '!sq100'}
                  set={[{ src: adminAvatar, alt: '子账号主图' }]}
                />
              )}
            /> */}
            <Column
              title="ID"
              key="adminId"
              dataIndex="adminId"
            />
            <Column
              title="名称"
              key="adminName"
              dataIndex="adminName"
              render={adminName => (
                <Ellipsis tooltip length={20}>
                  {adminName}
                </Ellipsis>
              )}
            />
            <Column
              title="手机号"
              key="adminPhone"
              dataIndex="adminPhone"
            />
            <Column
              title="邮箱"
              key="adminEmail"
              dataIndex="adminEmail"
              render={adminEmail => adminEmail || '--'}
            />
            <Column
              title="账户类型"
              key="parentId"
              dataIndex="parentId"
              render={parentId => parentId === '0' ? '母账号' : '子账号'}
            />
            <Column
              title="状态"
              key="adminStatus"
              dataIndex="adminStatus"
              render={status => (
                <Fragment>
                  {status === 1 && <Badge status="success" text="启用" />}
                  {status === 0 && <Badge status="error" text="禁用" />}
                </Fragment>
              )}
            />
            <Column
              title="授权渠道"
              key="authChannels"
              dataIndex="authChannels"
              render={authChannels => {
                authChannels = authChannels || []
                let name = []
                for (let item of authChannels) {
                  name.push(item.channelName)
                }
                return name.join('，')
              }}
            />
            <Column
              title="创建时间"
              dataIndex="adminCreateTime"
              key="adminCreateTime"
              render={adminCreateTime => Format.date(adminCreateTime, 'yyyy-MM-dd HH:mm')}
            />
            <Column
              title="操作"
              key="option"
              dataIndex="option"
              render={(option, record, index) => {
                return (
                  <Fragment>
                    <a onClick={this.opeUpdate.bind(this, record)}>编辑</a>
                    <Divider type="vertical" />
                    {record.adminStatus === 1 && (
                      <Popconfirm
                        title="确定禁用吗？"
                        onConfirm={this.handleStatus.bind(this, record.adminId, 0)}
                      >
                        <a>禁用</a>
                      </Popconfirm>
                    )}
                    {record.adminStatus === 0 && (
                      <Popconfirm
                        title="确定启用吗？"
                        onConfirm={this.handleStatus.bind(this, record.adminId, 1)}
                      >
                        <a>启用</a>
                      </Popconfirm>
                    )}
                    <Divider type="vertical" />
                    <Popconfirm
                      title="确定删除吗？"
                      onConfirm={this.deleteAdmin.bind(this, record.adminId)}
                    >
                      <a>删除</a>
                    </Popconfirm>
                  </Fragment>
                );
              }}
            />
          </Table>
        </Card>
        <AddManager
          info={this.state.info}
          drawerProps={{
            width: 600,
            title: this.state.actionType === 'add' ? '添加子账号' : '编辑子账号',
            visible: this.state.actionModal,
            onClose: () => this.setState({ actionModal: false }),
          }}
          refresh={() => {
            this.setState({ actionModal: false })
            this.getAdminPageList(1)
          }}
          type={this.state.actionType}
        />
      </PageHeaderWrapper>
    );
  }
}

export default ManagerList;
