import React, { Fragment } from 'react';
import { ExclamationCircleOutlined, PlusOutlined } from '@ant-design/icons';
import '@ant-design/compatible/assets/index.css';
import {
  Card,
  Table,
  notification,
  Button,
  Row,
  Col,
  Input,
  Divider,
  Select,
  Badge,
  Popconfirm,
  Modal,
} from 'antd';
import * as Format from '@/utils/Format';
import { getSecretKeyList, activateSecretKey, createSecretKey, deleteSecretKey, changeSecretKey } from '../services/api';
import router from 'umi/router';

const { Column } = Table;
const Option = Select.Option;


class SecretKeyList extends React.Component {
  constructor(props) {
    super(props);
    this.state = {
      userName: '',
    };
  }

  componentDidMount() {
    this.getSecretKeyList();
  }

  //获取秘钥列表
  getSecretKeyList() {
    const { loading } = this.state;
    const { channelId } = this.props
    if (loading) return;
    this.setState({ loading: true }, async () => {
      const res = await getSecretKeyList({ channelId });
      if (res.code === 'OK') {
        const list = res.data || [];
        this.setState({ list, loading: false });
      } else {
        this.setState({ loading: false });
      }
    });
  }

  //输入搜索名称
  handleSearchName(e) {
    this.setState({ userName: e.target.value });
  }

  //选择秘钥状态
  onSelectStatus(liveStatus) {
    this.setState({ liveStatus });
  }

  //跳转
  linkTo(url) {
    router.push(url);
  }

  testLog() {
    console.log(this.state);
  }

  //启用禁用标签
  activateSecretKey(secretId, isActivate) {
    const { statusLoading } = this.state;
    if (statusLoading) return;
    const { channelId } = this.props
    this.setState({ statusLoading: true }, async () => {
      const res = await activateSecretKey({ secretId, channelId, isActivate: isActivate === 1 ? 0 : 1 });
      if (res.success) {
        notification.success({
          message: `标签${isActivate === 1 ? '禁用' : '启用'}成功`,
        });
        this.setState({ statusLoading: false }, () => {
          this.getSecretKeyList()
        });
      } else {
        this.setState({ statusLoading: false });
      }
    });
  }

  //打开生成秘钥
  onCreate = () => {
    Modal.confirm({
      title: '确定生成新秘钥吗?',
      icon: <ExclamationCircleOutlined />,
      onOk: () => {
        this.createSecretKey()
      },
      onCancel() { },
    });
  }

  //生成秘钥
  createSecretKey = () => {
    const { channelId } = this.props
    if (this.state.createKeyLoading) return
    this.setState({ createKeyLoading: true }, async () => {
      const res = await createSecretKey({ channelId })
      if (res.success) {
        this.setState({ createKeyLoading: false }, () => {
          this.getSecretKeyList()
        })
      } else {
        this.setState({ createKeyLoading: false })
      }
    })
  }

  //删除秘钥
  deleteSecretKey = (secretId) => {
    const { channelId } = this.props
    if (this.state.deleteLoading) return
    this.setState({ deleteLoading: true }, async () => {
      const res = await deleteSecretKey({ secretId, channelId })
      if (res.success) {
        notification.success({
          message: '秘钥删除成功'
        })
        this.setState({ deleteLoading: false }, () => {
          this.getSecretKeyList()
        })
      } else {
        this.setState({ deleteLoading: false })
      }
    })
  }

  //变更秘钥
  changeSecretKey = (secretId, index) => {
    const { channelId } = this.props
    if (this.state.changeLoading) return
    this.setState({ changeLoading: true }, async () => {
      const res = await changeSecretKey({ secretId, channelId })
      if (res.success) {
        notification.success({
          message: '秘钥变更成功'
        })
        const { list } = this.state
        list[index].secretKey = res.data
        list[index].updateTime = Date.now()
        this.setState({ changeLoading: false })
      } else {
        this.setState({ changeLoading: false })
      }
    })
  }


  render() {
    const { list } = this.state;
    return (
      <Card
        title="秘钥列表"
        extra={
          <Button onClick={this.onCreate} icon={<PlusOutlined />} type="primary">添加秘钥</Button>
        }
      >
        <Table
          rowKey="secretId"
          loading={this.state.loading}
          dataSource={list}
        >
          <Column
            title="ID"
            key="secretId"
            dataIndex="secretId"
          />
          <Column
            title="秘钥"
            key="secretKey"
            dataIndex="secretKey"
          />
          <Column
            title="状态"
            key="isActivate"
            dataIndex="isActivate"
            render={isActivate => (
              <Fragment>
                {isActivate === 1 && <Badge status="success" text="启用" />}
                {isActivate === 0 && <Badge status="error" text="禁用" />}
              </Fragment>
            )}
          />
          <Column
            title="创建时间"
            dataIndex="createTime"
            key="createTime"
            render={createTime => Format.date(createTime, 'yyyy-MM-dd HH:mm:ss')}
          />
          <Column
            title="编辑时间"
            dataIndex="updateTime"
            key="updateTime"
            render={updateTime => Format.date(updateTime, 'yyyy-MM-dd HH:mm:ss')}
          />
          <Column
            title="操作"
            key="option"
            dataIndex="option"
            render={(option, record, index) => {
              return (
                <Fragment>
                  <Popconfirm
                    title={`确定${record.isActivate === 1 ? '禁用' : '启用'}吗？`}
                    onConfirm={this.activateSecretKey.bind(this, record.secretId, record.isActivate)}
                  >
                    <a>{record.isActivate === 1 ? '禁用' : '启用'}</a>
                  </Popconfirm>
                  <Divider type="vertical" />
                  <Popconfirm
                    title={`确定删除吗？`}
                    onConfirm={this.deleteSecretKey.bind(this, record.secretId)}
                  >
                    <a>删除</a>
                  </Popconfirm>
                  <Divider type="vertical" />
                  <Popconfirm
                    title={`确定变更吗？`}
                    onConfirm={this.changeSecretKey.bind(this, record.secretId, index)}
                  >
                    <a>变更</a>
                  </Popconfirm>

                </Fragment>
              );
            }}
          />
        </Table>
      </Card>
    );
  }
}

export default SecretKeyList;
